<div align="center">

<img src="https://lunary.ai/logo.png" style='border-radius: 12px;' width="50"/> 
<h1>Lunary Python SDK</h1>

**📈 Python monitoring for AI apps and agent**

[website](https://lunary.ai) - [docs](https://lunary.ai/docs/py/) - ![PyPI - Version](https://img.shields.io/pypi/v/lunary)

---

</div>

Use it with any LLM model and custom agents (not limited to OpenAI).

To get started, get a project ID by registering [here](https://lunary.ai).

## 🛠️ Installation

```bash
pip install lunary
```

## 📖 Documentation

Full docs are available [here](https://lunary.ai/docs/py).
